<img src=".figs/Global_new.png" alt="drawing" width="270"/>  

<div align="justify">

# Indicator 1.3.5: Leishmaniasis (v2024)

## Introduction

The leishmaniases are climate-sensitive zoonotic diseases caused by *Leishmania* protozoan parasites and transmitted by the bites of infectious female sand flies (Diptera: Psychodidae: *Phlebotominae*). Endemic in 99 countries or territories, leishmaniasis disproportionately affects the poorest and marginalised communities, with an estimated 700,000 to 1 million (underreported) new human cases globally every year. Furthermore, leishmaniasis is considered a climate-sensitive infectious disease, as sand fly species distributions tend to be restricted to warmer areas, although optimum temperature and humidity conditions for sand fly activity vary substantially between species and regions, influencing sand fly metabolism, and the development and survival of the sand fly life stages.

The **Leishmaniasis risk** indicator, published in the Lancet Countdown [Global](https://lancetcountdown.org/) report, tracks risk for leishmaniasis based one climatic suitablility and socio-economic factors, starting in 1951 until near present time.

## Methods
A machine learning approach was used, building on the work of [Carvalho et al. (2024)](https://www.sciencedirect.com/science/article/pii/S2666776224001388) to predict the risk for visceral and cutaneous leishmaniasis according to climatic suitability and socio-economic risks, in the baseline period 1960-2012 (via data from [Piggott et al., 2014](https://www.nature.com/articles/sdata201436)) and subsequently generated annual predictions for 1951-1959 and 2013-2024. The model was trained on a variety of climatic and socioeconomic features against a binary leishmaniasis absence/presence outcome variable.

#### Data sources

| Variable | Source | Spatial Resolution | Temporal range used | 
| ------ | ------ | ------ | ------ |
| Monthly 2 meter dew point temperature | [ERA5 (monthly)](https://cds.climate.copernicus.eu/datasets/reanalysis-era5-single-levels-monthly-means?tab=overview) | 0.25º x 0.25º | Jan 1940 - Present |
| Monthly 2 meter temperature | [ERA5 (monthly)](https://cds.climate.copernicus.eu/datasets/reanalysis-era5-single-levels-monthly-means?tab=overview) | 0.25º x 0.25º | Jan 1940 - Present |
| Monthly accumulated precipitation | [ERA5 (monthly)](https://cds.climate.copernicus.eu/datasets/reanalysis-era5-single-levels-monthly-means?tab=overview) | 0.25º x 0.25º | Jan 1940 - Present |
| Monthly soil water volume | [ERA5 (monthly)](https://cds.climate.copernicus.eu/datasets/reanalysis-era5-single-levels-monthly-means?tab=overview) | 0.25º x 0.25º | Jan 1940 - Present |
| Land cover | [Global Dynamic Land Cover](https://land.copernicus.eu/en/products/global-dynamic-land-cover/copernicus-global-land-service-land-cover-100m-collection-3-epoch-2019-globe) | 100m | 2019 |
| Altitude | [NASA SRTM](https://www.earthdata.nasa.gov/data/instruments/srtm) | 30m | 2014 |
| Population | [NASA GPW](https://cmr.earthdata.nasa.gov/search/concepts/C1597158029-SEDAC.html) | 1km | 2020 |
| Inequity | [UNDP HDI](https://hdr.undp.org/data-center/human-development-index#/indicies/HDI) | National | 2024 |

Using the raw data, the [WorldClim bioclimatic indciators](https://www.worldclim.org/data/bioclim.html) were calculated and the humidity and soil water data transformed in a similar way (e.g., annual mean, mean in driest, mean in warmest, mean in coldest, mean in wettest quarters). 

## How to read this folder

* [01_data_processing](01_data_processing): 
    * Import and transform climate variables
    * Compute relative humidity
    * Compute bioclimatic indicators
* [02_data_harmonisation](02_data_harmonisation):
    * Harmonise data to one file for fitting
    * Match spatial data
    * Calculate national averages 
* [03_model_fitting](03_model_fitting):
    * Fit prelinmary models to identify feature subset and correlations 
    * Identify best fit models
    * Complete model tuning
* [04_model_predictions](04_model_predictions):
    * Create the predictions dataset
    * Make predcitions with boostrap 
* [05_post_processing](05_post_processing): 
    * Compute spatial and temporal averages
    * Plot results

## Authors
##### - [Gina E C Charnley, PhD](https://www.bsc.es/charnley-georgina-eva-ceres)
##### - [Adria San Jose Plana, PhD](https://www.bsc.es/san-jose-plana-adria)
##### - Carla Maia, PhD 
##### - Orin Courtenay, PhD
##### - Prof. Jan Semenza
##### - [Prof. Rachel Lowe](https://www.bsc.es/lowe-rachel)

##### Contact: georgina.charnley@bsc.es
